#!/bin/bash
#########################################################################
#
# File:		check_phpprocs.sh
# Description:	Nagios check plugins to check php process in *nix.
# Language:	GNU Bourne-Again SHell
# Version:	1.0.0
# Date:		2015-1-16
# Author:	C1g
# Bog:		http://blog.C1gStudio.com
#########################################################################

path=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:~/bin
export PATH
STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3

warn_num=100
critical_num=200

usage(){
  echo -e "Usage: $0  -w|--warning warning threshold -c|--critical critical threshold"
}
select_arg(){
if [ $# -eq 0 ];then 
  return 1
fi
until [ $# -eq 0 ];do
  case $1 in
    -w|--warning)
      [ $# -lt 2 ] && return 1
      if ! echo $2 |grep -E -q "^[1-9][0-9]*$";then
        return 1
      fi
      warn_num=$2
	 shift 2
      ;;
    -c|--critical)
      [ $# -lt 2 ] && return 1
      if ! echo $2 |grep -E -q "^[1-9][0-9]*$";then
        return 1
      fi
      critical_num=$2
	shift 2
      ;;
    *)
	return 1 
     ;;
  esac
done
return 0
}

select_arg $@
[ $? -ne 0 ] && usage && exit $STATE_UNKNOWN

#echo "warn :$warn_num"
#echo "critical :$critical_num"

if [ $critical_num -lt $warn_num ];then
    usage
    exit $STATE_UNKNOWN
fi

total=`netstat -n | grep 127.0.0.1:9000 | wc -l`
if [ $total -lt $warn_num ];then
    echo "PHP OK - $total processes |PHP=$total;$warn_num;$critical_num;0"
    exit $STATE_OK
elif [ $total -ge $warn_num -a $total -lt $critical_num ];then
    echo "PHP WARNING - $total processes |PHP=$total;$warn_num;$critical_num;0"
    exit $STATE_WARNING
elif [ $total -ge $critical_num ];then
    echo "PHP CRITICAL - $total processes |PHP=$total;$warn_num;$critical_num;0"
    exit $STATE_CRITICAL
else
    echo "UNKNOWN STATE"
    exit $STATE_UNKNOWN
fi
